@@ -1,13 +1,11 @@
+# frozen_string_literal: true
+
 # font.rb : The Prawn font class
 #
 # Copyright May 2008, Gregory Brown / James Healy. All Rights Reserved.
 #
 # This is free software. Please see the LICENSE and COPYING files for details.
 #
-require_relative 'font/afm'
-require_relative 'font/ttf'
-require_relative 'font/dfont'
-require_relative 'font/ttc'
 require_relative 'font_metric_cache'
 
 module Prawn
@@ -35,7 +33,7 @@ module Prawn
     #
     # The :name parameter must be a string. It can be one of the 14 built-in
     # fonts supported by PDF, or the location of a TTF file. The
-    # Font::AFM::BUILT_INS array specifies the valid built in font values.
+    # Fonts::AFM::BUILT_INS array specifies the valid built in font values.
     #
     # If a ttf font is specified, the glyphs necessary to render your document
     # will be embedded in the rendered PDF. This should be your preferred option
@@ -96,6 +94,7 @@ module Prawn
     #
     def font_size(points = nil)
       return @font_size unless points
+
       size_before_yield = @font_size
       @font_size = points
       block_given? ? yield : return
@@ -280,6 +279,18 @@ module Prawn
   # Provides font information and helper functions.
   #
   class Font
+    require_relative 'fonts/afm'
+    require_relative 'fonts/ttf'
+    require_relative 'fonts/dfont'
+    require_relative 'fonts/otf'
+    require_relative 'fonts/ttc'
+
+    # @deprecated
+    AFM = Fonts::AFM
+    TTF = Fonts::TTF
+    DFont = Fonts::DFont
+    TTC = Fonts::TTC
+
     # The current font name
     attr_reader :name
 
@@ -290,14 +301,15 @@ module Prawn
     attr_reader :options
 
     # Shortcut interface for constructing a font object.  Filenames of the form
-    # *.ttf will call Font::TTF.new, *.dfont Font::DFont.new, *.ttc goes to
-    # Font::TTC.new, and anything else will be passed through to
-    # Font::AFM.new()
+    # *.ttf will call Fonts::TTF.new, *.dfont Fonts::DFont.new, *.ttc goes to
+    # Fonts::TTC.new, and anything else will be passed through to
+    # Fonts::AFM.new()
     def self.load(document, src, options = {})
       case font_format(src, options)
-      when 'ttf'   then TTF.new(document, src, options)
+      when 'ttf' then TTF.new(document, src, options)
+      when 'otf' then Fonts::OTF.new(document, src, options)
       when 'dfont' then DFont.new(document, src, options)
-      when 'ttc'   then TTC.new(document, src, options)
+      when 'ttc' then TTC.new(document, src, options)
       else AFM.new(document, src, options)
       end
     end
@@ -306,10 +318,11 @@ module Prawn
       return options.fetch(:format, 'ttf') if src.respond_to? :read
 
       case src.to_s
-      when /\.ttf$/i   then return 'ttf'
-      when /\.dfont$/i then return 'dfont'
-      when /\.ttc$/i   then return 'ttc'
-      else return 'afm'
+      when /\.ttf$/i   then 'ttf'
+      when /\.otf$/i   then 'otf'
+      when /\.dfont$/i then 'dfont'
+      when /\.ttc$/i   then 'ttc'
+      else 'afm'
       end
     end
 
@@ -355,8 +368,11 @@ module Prawn
     # Destructive version of normalize_encoding; normalizes the encoding of a
     # string in place.
     #
+    # @deprecated
     def normalize_encoding!(str)
-      str.replace(normalize_encoding(str))
+      warn 'Font#normalize_encoding! is deprecated. ' \
+        'Please use non-mutating version Font#normalize_encoding instead.'
+      str.dup.replace(normalize_encoding(str))
     end
 
     # Gets height of current font in PDF points at the given font size
@@ -384,7 +400,7 @@ module Prawn
     end
 
     def identifier_for(subset) #:nodoc:
-      "#{@identifier}.#{subset}"
+      "#{@identifier}.#{subset}".to_sym
     end
 
     def inspect #:nodoc:
@@ -417,13 +433,14 @@ module Prawn
       loop do
         key = :"F#{font_count}"
         break if key_is_unique?(key)
+
         font_count += 1
       end
       key
     end
 
     def key_is_unique?(test_key)
-      !@document.state.page.fonts.keys.any? do |key|
+      @document.state.page.fonts.keys.none? do |key|
         key.to_s.start_with?("#{test_key}.")
       end
     end
