@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # transformation.rb: Implements rotate, translate, skew, scale and a generic
 #                     transformation_matrix
 #
@@ -47,6 +49,7 @@ module Prawn
           transformation_matrix(cos, sin, -sin, cos, 0, 0, &block)
         else
           raise Prawn::Errors::BlockRequired unless block_given?
+
           x = options[:origin][0] + bounds.absolute_left
           y = options[:origin][1] + bounds.absolute_bottom
           x_prime = x * cos - y * sin
@@ -116,6 +119,7 @@ module Prawn
           transformation_matrix(factor, 0, 0, factor, 0, 0, &block)
         else
           raise Prawn::Errors::BlockRequired unless block_given?
+
           x = options[:origin][0] + bounds.absolute_left
           y = options[:origin][1] + bounds.absolute_bottom
           x_prime = factor * x
@@ -145,7 +149,7 @@ module Prawn
           raise ArgumentError,
             'Transformation matrix must have exacty 6 elements'
         end
-        values = matrix.map { |x| format '%.5f', x }.join(' ')
+        values = matrix.map { |x| x.to_f.round(5) }.join(' ')
         save_graphics_state if block_given?
 
         add_to_transformation_stack(*matrix)
