@@ -1,5 +1,7 @@
 # encoding: ASCII-8BIT
 
+# frozen_string_literal: true
+
 # png.rb : Extracts the data from a PNG that is needed for embedding
 #
 # Based on some similar code in PDF::Writer by Austin Ziegler
@@ -9,8 +11,6 @@
 # This is free software. Please see the LICENSE and COPYING files for details.
 
 require 'stringio'
-require 'enumerator'
-
 module Prawn
   module Images
     # A convenience class that wraps the logic for extracting the parts
@@ -38,12 +38,12 @@ module Prawn
 
         data.read(8) # Skip the default header
 
-        @palette = ''
-        @img_data = ''
+        @palette = +''
+        @img_data = +''
         @transparency = {}
 
         loop do
-          chunk_size = data.read(4).unpack('N')[0]
+          chunk_size = data.read(4).unpack1('N')
           section = data.read(4)
           case section
           when 'IHDR'
@@ -72,7 +72,7 @@ module Prawn
             when 0
               # Greyscale. Corresponding to entries in the PLTE chunk.
               # Grey is two bytes, range 0 .. (2 ^ bit-depth) - 1
-              grayval = data.read(chunk_size).unpack('n').first
+              grayval = data.read(chunk_size).unpack1('n')
               @transparency[:grayscale] = grayval
             when 2
               # True colour with proper alpha channel.
@@ -97,9 +97,9 @@ module Prawn
       def colors
         case color_type
         when 0, 3, 4
-          return 1
+          1
         when 2, 6
-          return 3
+          3
         end
       end
 
@@ -321,7 +321,7 @@ module Prawn
           alpha.putc filter
 
           width.times do
-            color = data.read(1).unpack('C').first
+            color = data.read(1).unpack1('C')
             alpha.putc alpha_palette[color]
           end
         end
