@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # soft_mask.rb : Implements soft-masking
 #
 # Copyright September 2012, Alexander Mankuta. All Rights Reserved.
@@ -73,7 +75,7 @@ module Prawn
         renderer.add_content "/#{soft_mask_registry[registry_key]} gs"
       else
         masks = page.resources[:ExtGState] ||= {}
-        id = masks.empty? ? 'GS1' : masks.keys.sort.last.succ
+        id = masks.empty? ? 'GS1' : masks.keys.max.succ
         masks[id] = g_state
 
         soft_mask_registry[registry_key] = id
