@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # text.rb : Implements PDF text primitives
 #
 # Copyright May 2008, Gregory Brown. All Rights Reserved.
@@ -6,8 +8,6 @@
 
 require 'zlib'
 
-require 'pdf/core/text'
-
 require_relative 'text/formatted'
 require_relative 'text/box'
 
@@ -17,11 +17,11 @@ module Prawn
     include Prawn::Text::Formatted
 
     # No-Break Space
-    NBSP = "\u00A0".freeze
+    NBSP = "\u00A0"
     # Zero Width Space (indicate word boundaries without a space)
-    ZWSP = "\u200B".freeze
+    ZWSP = "\u200B"
     # Soft Hyphen (invisible, except when causing a line break)
-    SHY = "\u00AD".freeze
+    SHY = "\u00AD"
 
     # @group Stable API
 
@@ -151,6 +151,7 @@ module Prawn
     #
     def text(string, options = {})
       return false if string.nil?
+
       # we modify the options. don't change the user's hash
       options = options.dup
 
@@ -281,7 +282,7 @@ module Prawn
       text = text.to_s.dup
       save_font do
         process_text_options(options)
-        font.normalize_encoding!(text)
+        text = font.normalize_encoding(text)
         font_size(options[:size]) { draw_text!(text, options) }
       end
     end
@@ -293,9 +294,9 @@ module Prawn
       unless font.unicode? || font.class.hide_m17n_warning || text.ascii_only?
         warn "PDF's built-in fonts have very limited support for " \
              "internationalized text.\nIf you need full UTF-8 support, " \
-             "consider using a TTF font instead.\n\nTo disable this " \
+             "consider using an external font instead.\n\nTo disable this " \
              "warning, add the following line to your code:\n" \
-             "Prawn::Font::AFM.hide_m17n_warning = true\n"
+             "Prawn::Fonts::AFM.hide_m17n_warning = true\n"
 
         font.class.hide_m17n_warning = true
       end
@@ -409,10 +410,11 @@ module Prawn
       elsif options[:align]
         raise ArgumentError, 'The :align option does not work with draw_text'
       end
+
       if options[:kerning].nil?
         options[:kerning] = default_kerning?
       end
-      valid_options = PDF::Core::Text::VALID_OPTIONS + [:at, :rotate]
+      valid_options = PDF::Core::Text::VALID_OPTIONS + %i[at rotate]
       Prawn.verify_options(valid_options, options)
       options
     end
@@ -438,7 +440,7 @@ module Prawn
       options.delete(:indent_paragraphs)
     end
 
-    def move_text_position(dy)
+    def move_text_position(amount)
       bottom =
         if @bounding_box.stretchy?
           @margin_box.absolute_bottom
@@ -446,9 +448,9 @@ module Prawn
           @bounding_box.absolute_bottom
         end
 
-      @bounding_box.move_past_bottom if (y - dy) < bottom
+      @bounding_box.move_past_bottom if (y - amount) < bottom
 
-      self.y -= dy
+      self.y -= amount
     end
   end
 end
