@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # core/text/formatted/line_wrap.rb : Implements individual line wrapping of
 #                                    formatted text
 #
@@ -39,7 +41,7 @@ module Prawn
           # rubocop: disable Lint/AssignmentInCondition
           while fragment = @arranger.next_string
             # rubocop: enable Lint/AssignmentInCondition
-            @fragment_output = ''
+            @fragment_output = +''
 
             fragment.lstrip! if first_fragment_on_this_line?(fragment)
             next if empty_line?(fragment)
@@ -91,11 +93,11 @@ module Prawn
             false
           else
             tokenize(fragment).each do |segment|
-              if segment == zero_width_space(segment.encoding)
-                segment_width = 0
-              else
-                segment_width = @document.width_of(segment, kerning: @kerning)
-              end
+              segment_width = if segment == zero_width_space(segment.encoding)
+                                0
+                              else
+                                @document.width_of(segment, kerning: @kerning)
+                              end
 
               if @accumulated_width + segment_width <= @width
                 @accumulated_width += segment_width
@@ -242,6 +244,7 @@ module Prawn
               !fragment.strip.empty?
             raise Prawn::Errors::CannotFit
           end
+
           @arranger.update_last_string(
             @fragment_output,
             remaining_text,
@@ -284,8 +287,7 @@ module Prawn
         end
 
         def update_line_status_based_on_last_output
-          if @fragment_output =~
-              word_division_scan_pattern(@fragment_output.encoding)
+          if @fragment_output&.match?(word_division_scan_pattern(@fragment_output.encoding))
             @line_contains_more_than_one_word = true
           end
         end
