@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # The base unit in Prawn is the PDF Point. One PDF Point is equal to 1/72 of
 # an inch.
 #
@@ -15,7 +17,7 @@ filename = File.basename(__FILE__).gsub('.rb', '.pdf')
 Prawn::ManualBuilder::Example.generate(filename) do
   require 'prawn/measurement_extensions'
 
-  [:mm, :cm, :dm, :m, :in, :yd, :ft].each do |measurement|
+  %i[mm cm dm m in yd ft].each do |measurement|
     text "1 #{measurement} in PDF Points: #{1.send(measurement)} pt"
     move_down 5.mm
   end
