@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Most font families come with some styles other than normal. Most common are
 # <code>bold</code>, <code>italic</code> and <code>bold_italic</code>.
 #
@@ -9,10 +11,10 @@ require_relative '../example_helper'
 
 filename = File.basename(__FILE__).gsub('.rb', '.pdf')
 Prawn::ManualBuilder::Example.generate(filename) do
-  ['Courier', 'Helvetica', 'Times-Roman'].each do |example_font|
+  %w[Courier Helvetica Times-Roman].each do |example_font|
     move_down 20
 
-    [:bold, :bold_italic, :italic, :normal].each do |style|
+    %i[bold bold_italic italic normal].each do |style|
       font example_font, style: style
       text "I'm writing in #{example_font} (#{style})"
     end
