@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Rotating text is best avoided on free flowing text, so this example
 # will only use the <code>text_box</code> method as we can have much more
 # control over its output.
@@ -29,7 +31,7 @@ Prawn::ManualBuilder::Example.generate(filename) do
     rotate: angle, rotate_around: :center
   )
 
-  [:lower_left, :upper_left, :lower_right, :upper_right]
+  %i[lower_left upper_left lower_right upper_right]
     .each_with_index do |corner, index|
     y -= 100 if index == 2
     stroke_rectangle [x + (index % 2) * 200, y], width, height
