@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Prints a list of all of the glyphs that can be rendered by Adobe's built
 # in fonts, along with their character widths and WinAnsi codes.  Be sure
 # to pass these glyphs as UTF-8, and Prawn will transcode them for you.
@@ -22,6 +24,7 @@ Prawn::ManualBuilder::Example.generate(filename) do
 
   Prawn::Encoding::WinAnsi::CHARACTERS.each_with_index do |name, index|
     next if name == '.notdef'
+
     y -= FONT_SIZE
 
     if y < FONT_SIZE
@@ -29,11 +32,11 @@ Prawn::ManualBuilder::Example.generate(filename) do
       x += 170
     end
 
-    code = format('%d.', index)
+    code = format('%<index>d.', index: index)
     char = index.chr.force_encoding(::Encoding::Windows_1252)
 
     width = 1000 * width_of(char, size: FONT_SIZE) / FONT_SIZE
-    size = format('%d', width)
+    size = format('%<width>d', width: width)
 
     data = [code, nil, char, size, nil, name]
     dx = x
@@ -48,7 +51,7 @@ Prawn::ManualBuilder::Example.generate(filename) do
         end
 
         text_box(
-          field.force_encoding('windows-1252').encode('UTF-8'),
+          field.dup.force_encoding('windows-1252').encode('UTF-8'),
           at: [dx + offset, y]
         )
       end
