@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'spec_helper'
 require 'tempfile'
 
@@ -32,7 +34,7 @@ describe Prawn::Document do
 
   describe 'when generating a document with a custom text formatter' do
     it 'uses the provided text formatter' do
-      class TestTextFormatter
+      text_formatter = Class.new do
         def self.format(string)
           [
             {
@@ -49,7 +51,7 @@ describe Prawn::Document do
           ]
         end
       end
-      pdf = described_class.new text_formatter: TestTextFormatter
+      pdf = described_class.new text_formatter: text_formatter
       pdf.text 'Dr. Who?', inline_format: true
       text = PDF::Inspector::Text.analyze(pdf.render)
       expect(text.strings.first).to eq("Just 'The Doctor'.")
@@ -153,6 +155,54 @@ describe Prawn::Document do
         described_class.new.start_new_page({ margin: 0 }.freeze)
       end.to_not raise_error
     end
+
+    it 'sets individual page margins' do
+      doc = described_class.new
+      doc.start_new_page(top_margin: 42)
+      expect(doc.page.margins[:top]).to eq(42)
+    end
+  end
+
+  describe '#delete_page(index)' do
+    before do
+      pdf.text 'Page one'
+      pdf.start_new_page
+      pdf.text 'Page two'
+      pdf.start_new_page
+      pdf.text 'Page three'
+    end
+
+    it 'destroy a specific page of the document' do
+      pdf.delete_page(1)
+      expect(pdf.page_number).to eq(2)
+      text_analysis = PDF::Inspector::Text.analyze(pdf.render)
+      expect(text_analysis.strings).to eq(['Page one', 'Page three'])
+    end
+
+    it 'destroy the last page of the document' do
+      pdf.delete_page(-1)
+      expect(pdf.page_number).to eq(2)
+      text_analysis = PDF::Inspector::Text.analyze(pdf.render)
+      expect(text_analysis.strings).to eq(['Page one', 'Page two'])
+    end
+
+    context 'with an invalid index' do
+      let(:expected_content) { ['Page one', 'Page two', 'Page three'] }
+
+      it 'does not destroy an invalid positve index' do
+        pdf.delete_page(42)
+        expect(pdf.page_number).to eq(3)
+        text_analysis = PDF::Inspector::Text.analyze(pdf.render)
+        expect(text_analysis.strings).to eq(expected_content)
+      end
+
+      it 'does not destroy an invalid negative index' do
+        pdf.delete_page(-42)
+        expect(pdf.page_number).to eq(3)
+        text_analysis = PDF::Inspector::Text.analyze(pdf.render)
+        expect(text_analysis.strings).to eq(expected_content)
+      end
+    end
   end
 
   describe '#page_number' do
@@ -350,7 +400,7 @@ describe Prawn::Document do
     end
 
     (PDF::Core::PageGeometry::SIZES.keys - ['LETTER']).each do |k|
-      it "should provide #{k} geometry" do
+      it "provides #{k} geometry" do
         pdf = described_class.new(page_size: k)
         pages = PDF::Inspector::Page.analyze(pdf.render).pages
         expect(pages.first[:size]).to eq(PDF::Core::PageGeometry::SIZES[k])
@@ -566,7 +616,7 @@ describe Prawn::Document do
       expect(pdf).to_not have_received(:text_box)
     end
 
-    context 'start_count_at option' do
+    context 'with start_count_at option' do
       [1, 2].each do |startat|
         context "equal to #{startat}" do
           it 'increments the pages' do
@@ -599,7 +649,7 @@ describe Prawn::Document do
       end
     end
 
-    context 'total_pages option' do
+    context 'with total_pages option' do
       it 'allows the total pages count to be overridden' do
         2.times { pdf.start_new_page }
         allow(pdf).to receive(:text_box)
@@ -610,8 +660,8 @@ describe Prawn::Document do
       end
     end
 
-    context 'special page filter' do
-      context 'such as :odd' do
+    context 'with special page filter' do
+      describe 'such as :odd' do
         it 'increments the pages' do
           3.times { pdf.start_new_page }
           allow(pdf).to receive(:text_box)
@@ -623,7 +673,7 @@ describe Prawn::Document do
         end
       end
 
-      context 'missing' do
+      describe 'missing' do
         it 'does not print any page numbers' do
           3.times { pdf.start_new_page }
           allow(pdf).to receive(:text_box)
@@ -634,8 +684,8 @@ describe Prawn::Document do
       end
     end
 
-    context 'given both a special page filter and a start_count_at parameter' do
-      context 'such as :odd and 7' do
+    context 'with both a special page filter and a start_count_at parameter' do
+      describe 'such as :odd and 7' do
         it 'increments the pages' do
           3.times { pdf.start_new_page }
           allow(pdf).to receive(:text_box)
@@ -654,7 +704,8 @@ describe Prawn::Document do
           expect(pdf).to have_received(:text_box).with('7 3', height: 50)
         end
       end
-      context 'some crazy proc and 2' do
+
+      context 'with some crazy proc and 2' do
         it 'increments the pages' do
           6.times { pdf.start_new_page }
           options = {
@@ -685,7 +736,7 @@ describe Prawn::Document do
       end
     end
 
-    context 'height option' do
+    describe 'height option' do
       before do
         pdf.start_new_page
       end
@@ -718,7 +769,7 @@ describe Prawn::Document do
     end
 
     it 'returns nil given no filter' do
-      expect(pdf.page_match?(:nil, 1)).to be_falsey
+      expect(pdf).to_not be_page_match(:nil, 1)
     end
 
     it 'must provide an :all filter' do
@@ -729,7 +780,7 @@ describe Prawn::Document do
     it 'must provide an :odd filter' do
       odd, even = (1..pdf.page_count).partition(&:odd?)
       expect(odd.all? { |i| pdf.page_match?(:odd, i) }).to eq true
-      expect(even.any? { |i| pdf.page_match?(:odd, i) }).to be_falsey
+      expect(even).to_not(be_any { |i| pdf.page_match?(:odd, i) })
     end
 
     it 'must be able to filter by an array of page numbers' do
