@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'spec_helper'
 
 describe Prawn::Graphics do
@@ -12,8 +14,7 @@ describe Prawn::Graphics do
       expect(line_drawing.points).to eq([[100, 600], [100, 500]])
     end
 
-    it 'should draw two lines at (100,600) to (100,500) ' \
-      'and (75,100) to (50,125)' do
+    it 'draws two lines at (100,600) to (100,500) and (75,100) to (50,125)' do
       pdf.line(100, 600, 100, 500)
       pdf.line(75, 100, 50, 125)
 
@@ -67,6 +68,7 @@ describe Prawn::Graphics do
         line_drawing = PDF::Inspector::Graphics::Line.analyze(pdf.render)
         expect(line_drawing.points).to eq([[350, 300], [350, 400]])
       end
+
       it 'requires a y coordinate' do
         expect { pdf.vertical_line(400, 500) }
           .to raise_error(ArgumentError)
@@ -116,6 +118,7 @@ describe Prawn::Graphics do
 
   describe 'When drawing a rounded rectangle' do
     before { pdf.rounded_rectangle([50, 550], 50, 100, 10) }
+
     let(:original_point) do
       curve = PDF::Inspector::Graphics::Curve.analyze(pdf.render)
       curve_points = curve.coords.each_slice(2).to_a
@@ -245,6 +248,10 @@ describe Prawn::Graphics do
       expect { pdf.fill_color 'zcff00' }.to raise_error(ArgumentError)
     end
 
+    it 'raises an error for a color string with invalid characters' do
+      expect { pdf.fill_color 'f0f0f?' }.to raise_error(ArgumentError)
+    end
+
     it 'resets the colors on each new page if they have been defined' do
       pdf.fill_color 'ccff00'
 
@@ -295,6 +302,23 @@ describe Prawn::Graphics do
         end).to eq true
       end
 
+      it 'creates a unique ID for each pattern resource' do
+        pdf.fill_gradient(
+          [256, 512],
+          [356, 512],
+          'ffffff', 'fe00ff'
+        )
+        pdf.fill_gradient(
+          [256, 256],
+          [356, 256],
+          'ffffff', '0000ff'
+        )
+
+        str = pdf.render
+        pattern_ids = str.scan(/SP\h{40}\s+scn/)
+        expect(pattern_ids.uniq.length).to eq 2
+      end
+
       it 'fill_gradient should set fill color to the pattern' do
         pdf.fill_gradient(
           [0, pdf.bounds.height],
@@ -411,7 +435,7 @@ describe Prawn::Graphics do
     end
 
     describe 'gradient transformations' do
-      subject do
+      subject(:transformations) do
         pdf.scale 2 do
           pdf.translate 40, 40 do
             pdf.fill_gradient [0, 10], [15, 15], 'FF0000', '0000FF', opts
@@ -429,7 +453,7 @@ describe Prawn::Graphics do
 
         it 'uses the transformation stack to translate user co-ordinates to '\
           'document co-ordinates required by /Pattern' do
-          is_expected.to eq([[2, 0, 0, 2, 80, 100]])
+          expect(transformations).to eq([[2, 0, 0, 2, 80, 100]])
         end
       end
 
@@ -437,7 +461,7 @@ describe Prawn::Graphics do
         let(:opts) { { apply_transformations: false } }
 
         it "doesn't transform the gradient" do
-          is_expected.to eq([[1, 0, 0, 1, 0, 10]])
+          expect(transformations).to eq([[1, 0, 0, 1, 0, 10]])
         end
       end
 
@@ -446,7 +470,7 @@ describe Prawn::Graphics do
 
         it "doesn't transform the gradient and displays a warning" do
           allow(pdf).to receive(:warn).twice
-          is_expected.to eq([[1, 0, 0, 1, 0, 10]])
+          expect(transformations).to eq([[1, 0, 0, 1, 0, 10]])
           expect(pdf).to have_received(:warn).twice
         end
       end
@@ -607,7 +631,7 @@ describe Prawn::Graphics do
       'the initializer' do
       new_state = PDF::Core::GraphicState.new(pdf.graphic_state)
 
-      [:color_space, :dash, :fill_color, :stroke_color].each do |attr|
+      %i[color_space dash fill_color stroke_color].each do |attr|
         expect(new_state.send(attr)).to eq(pdf.graphic_state.send(attr))
         expect(new_state.send(attr)).to_not equal(pdf.graphic_state.send(attr))
       end
@@ -616,7 +640,7 @@ describe Prawn::Graphics do
     it 'copies mutable attributes when duping' do
       new_state = pdf.graphic_state.dup
 
-      [:color_space, :dash, :fill_color, :stroke_color].each do |attr|
+      %i[color_space dash fill_color stroke_color].each do |attr|
         expect(new_state.send(attr)).to eq(pdf.graphic_state.send(attr))
         expect(new_state.send(attr)).to_not equal(pdf.graphic_state.send(attr))
       end
@@ -629,15 +653,15 @@ describe Prawn::Graphics do
 
     it 'sends the right content on transformation_matrix' do
       allow(pdf.renderer).to receive(:add_content)
-        .with('1.00000 0.00000 0.12346 -1.00000 5.50000 20.00000 cm')
+        .with('1.0 0.0 0.12346 -1.0 5.5 20.0 cm')
       pdf.transformation_matrix 1, 0, 0.123456789, -1.0, 5.5, 20
       expect(pdf.renderer).to have_received(:add_content)
-        .with('1.00000 0.00000 0.12346 -1.00000 5.50000 20.00000 cm')
+        .with('1.0 0.0 0.12346 -1.0 5.5 20.0 cm')
     end
 
     it 'uses fixed digits with very small number' do
       values = Array.new(6, 0.000000000001)
-      string = Array.new(6, '0.00000').join ' '
+      string = Array.new(6, '0.0').join ' '
       allow(pdf.renderer).to receive(:add_content).with("#{string} cm")
       pdf.transformation_matrix(*values)
       expect(pdf.renderer).to have_received(:add_content).with("#{string} cm")
@@ -651,7 +675,7 @@ describe Prawn::Graphics do
 
     it 'saves the graphics state inside the given block' do
       values = Array.new(6, 0.000000000001)
-      string = Array.new(6, '0.00000').join ' '
+      string = Array.new(6, '0.0').join ' '
 
       allow(pdf).to receive(:save_graphics_state).with(no_args)
       allow(pdf.renderer).to receive(:add_content).with(any_args).twice
@@ -742,10 +766,6 @@ describe Prawn::Graphics do
           pdf.rotate(angle, origin: [x, y])
         end.to raise_error(Prawn::Errors::BlockRequired)
       end
-
-      def reduce_precision(float)
-        (format '%.5f', float).to_f
-      end
     end
 
     describe '#translate' do
@@ -808,10 +828,10 @@ describe Prawn::Graphics do
           pdf.scale(factor, origin: [x, y])
         end.to raise_error(Prawn::Errors::BlockRequired)
       end
-
-      def reduce_precision(float)
-        (format '%.5f', float).to_f
-      end
     end
   end
+
+  def reduce_precision(float)
+    float.round(5)
+  end
 end
