@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'spec_helper'
 
 describe Prawn::Text::Box do
@@ -56,8 +58,8 @@ describe Prawn::Text::Box do
     expect(text.strings[1]).to eq("I'm fine, thank you.")
   end
 
-  it 'should only require enough space for the descender and the ascender ' \
-    'when determining whether a line can fit' do
+  it 'only requires enough space for the descender and the ascender '\
+     'when determining whether a line can fit' do
     text = 'Oh hai text rect'
     options = {
       document: pdf,
@@ -110,8 +112,7 @@ describe Prawn::Text::Box do
   end
 
   describe '#line_gap' do
-    it 'should == the line gap of the font when using a single ' \
-      'font and font size' do
+    it '==S the line gap of the font when using a single font and font size' do
       string = "Hello world, how are you?\nI'm fine, thank you."
       text_box = described_class.new(string, document: pdf)
       text_box.render
@@ -140,8 +141,8 @@ describe Prawn::Text::Box do
   end
 
   describe '#height without leading' do
-    it 'should == the sum of the height of each line, ' \
-      'not including the space below the last line' do
+    it 'is the sum of the height of each line, not including the space below '\
+       'the last line' do
       text = "Oh hai text rect.\nOh hai text rect."
       options = { document: pdf }
       text_box = described_class.new(text, options)
@@ -152,8 +153,8 @@ describe Prawn::Text::Box do
   end
 
   describe '#height with leading' do
-    it 'should == the sum of the height of each line plus leading, ' \
-      'but not including the space below the last line' do
+    it 'is the sum of the height of each line plus leading, but not including '\
+       'the space below the last line' do
       text = "Oh hai text rect.\nOh hai text rect."
       leading = 12
       options = { document: pdf, leading: leading }
@@ -327,7 +328,7 @@ describe Prawn::Text::Box do
       }
     end
 
-    context ':rotate_around option of :center' do
+    context 'with :rotate_around option of :center' do
       it 'draws content to the page rotated about the center of the text' do
         options[:rotate_around] = :center
         text_box = described_class.new(text, options)
@@ -356,7 +357,7 @@ describe Prawn::Text::Box do
       end
     end
 
-    context ':rotate_around option of :upper_left' do
+    context 'with :rotate_around option of :upper_left' do
       it 'draws content to the page rotated about the upper left corner of '\
         'the text' do
         options[:rotate_around] = :upper_left
@@ -384,7 +385,7 @@ describe Prawn::Text::Box do
       end
     end
 
-    context 'default :rotate_around' do
+    context 'with default :rotate_around' do
       it 'draws content to the page rotated about the upper left corner of '\
         'the text' do
         text_box = described_class.new(text, options)
@@ -411,7 +412,7 @@ describe Prawn::Text::Box do
       end
     end
 
-    context ':rotate_around option of :upper_right' do
+    context 'with :rotate_around option of :upper_right' do
       it 'draws content to the page rotated about the upper right corner of '\
         'the text' do
         options[:rotate_around] = :upper_right
@@ -441,7 +442,7 @@ describe Prawn::Text::Box do
       end
     end
 
-    context ':rotate_around option of :lower_right' do
+    context 'with :rotate_around option of :lower_right' do
       it 'draws content to the page rotated about the lower right corner of '\
         'the text' do
         options[:rotate_around] = :lower_right
@@ -471,7 +472,7 @@ describe Prawn::Text::Box do
       end
     end
 
-    context ':rotate_around option of :lower_left' do
+    context 'with :rotate_around option of :lower_left' do
       it 'draws content to the page rotated about the lower left corner of '\
         'the text' do
         options[:rotate_around] = :lower_left
@@ -521,8 +522,8 @@ describe Prawn::Text::Box do
       end
     end
 
-    it 'should use the parent-box bottom if in a stretchy bbox and ' \
-      'overflow is :expand, even with an explicit height' do
+    it 'uses the parent-box bottom if in a stretchy bbox and overflow is '\
+       ':expand, even with an explicit height' do
       pdf.bounding_box([0, pdf.cursor], width: pdf.bounds.width) do
         target_height = pdf.y - pdf.bounds.bottom
         text = "Oh hai\n" * 60
@@ -663,7 +664,7 @@ describe Prawn::Text::Box do
     end
   end
 
-  context 'printing UTF-8 string with higher bit characters' do
+  context 'when printing UTF-8 string with higher bit characters' do
     let(:text) { '©' }
 
     let(:text_box) do
@@ -714,7 +715,7 @@ describe Prawn::Text::Box do
       }
     end
 
-    context 'truncated overflow' do
+    context 'when truncated overflow' do
       let(:text_box) do
         described_class.new(text, options.merge(overflow: :truncate))
       end
@@ -756,7 +757,7 @@ describe Prawn::Text::Box do
       end
     end
 
-    context 'truncated with text and size taken from the manual' do
+    context 'when truncated with text and size taken from the manual' do
       it 'returns the right text' do
         text = 'This is the beginning of the text. It will be cut somewhere ' \
           'and the rest of the text will procede to be rendered this time by '\
@@ -775,7 +776,7 @@ describe Prawn::Text::Box do
       end
     end
 
-    context 'expand overflow' do
+    context 'when expand overflow' do
       let(:text_box) do
         described_class.new(text, options.merge(overflow: :expand))
       end
@@ -799,7 +800,7 @@ describe Prawn::Text::Box do
       end
     end
 
-    context 'shrink_to_fit overflow' do
+    context 'when shrink_to_fit overflow' do
       let(:text_box) do
         described_class.new(
           text,
@@ -818,9 +819,7 @@ describe Prawn::Text::Box do
       it 'render returns an empty string because no text remains unprinted' do
         expect(text_box.render).to eq('')
       end
-    end
 
-    context 'shrink_to_fit overflow' do
       it 'does not drop below the minimum font size' do
         options[:overflow] = :shrink_to_fit
         options[:min_font_size] = 10.1
@@ -1018,7 +1017,7 @@ describe Prawn::Text::Box do
       expect(text_box.text).to eq(expect)
     end
 
-    it 'wraps lines comprised of a single word of the bounds when '\
+    it 'wraps lines comprised of a single non-alpha word of the bounds when '\
       'wrapping text' do
       text = '©' * 30
 
@@ -1031,8 +1030,8 @@ describe Prawn::Text::Box do
 
       text_box.render
 
-      expected = '©' * 25 + "\n" + '©' * 5
-      pdf.font.normalize_encoding!(expected)
+      expected = +'©' * 25 + "\n" + '©' * 5
+      expected = pdf.font.normalize_encoding(expected)
       expected = expected.force_encoding(Encoding::UTF_8)
       expect(text_box.text).to eq(expected)
     end
@@ -1104,7 +1103,7 @@ describe Prawn::Text::Box do
   end
 
   def reduce_precision(float)
-    (format '%.5f', float).to_f
+    float.round(5)
   end
 
   def first_line(str)
