@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'spec_helper'
 
 describe Prawn::Text::Formatted::Box do
@@ -260,7 +262,7 @@ describe Prawn::Text::Formatted::Box do
       expect(fonts_used[1]).to match(/Kai/)
     end
 
-    it 'should omit the fallback fonts overhead when passing an empty array ' \
+    it 'omits the fallback fonts overhead when passing an empty array ' \
       'as the :fallback_fonts' do
       pdf.font('Kai')
 
@@ -299,33 +301,63 @@ describe Prawn::Text::Formatted::Box do
   end
 
   describe 'Text::Formatted::Box#extensions' do
+    let(:formatted_wrap_override) do
+      Module.new do
+        # rubocop: disable RSpec/InstanceVariable
+        def wrap(_array)
+          initialize_wrap([{ text: 'all your base are belong to us' }])
+          @line_wrap.wrap_line(
+            document: @document,
+            kerning: @kerning,
+            width: 10_000,
+            arranger: @arranger
+          )
+          fragment = @arranger.retrieve_fragment
+          format_and_draw_fragment(fragment, 0, @line_wrap.width, 0)
+
+          []
+        end
+        # rubocop: enable RSpec/InstanceVariable
+      end
+    end
+
     it 'is able to override default line wrapping' do
-      described_class.extensions << TestFormattedWrapOverride
+      described_class.extensions << formatted_wrap_override
       pdf.formatted_text_box([{ text: 'hello world' }], {})
-      described_class.extensions.delete(TestFormattedWrapOverride)
+      described_class.extensions.delete(formatted_wrap_override)
       text = PDF::Inspector::Text.analyze(pdf.render)
       expect(text.strings[0]).to eq('all your base are belong to us')
     end
 
     it 'overrides Text::Formatted::Box line wrapping does not affect ' \
       'Text::Box wrapping' do
-      described_class.extensions << TestFormattedWrapOverride
+      described_class.extensions << formatted_wrap_override
       pdf.text_box('hello world', {})
-      described_class.extensions.delete(TestFormattedWrapOverride)
+      described_class.extensions.delete(formatted_wrap_override)
       text = PDF::Inspector::Text.analyze(pdf.render)
       expect(text.strings[0]).to eq('hello world')
     end
 
     it "overring Text::Box line wrapping doesn't override Text::Box wrapping" do
-      Prawn::Text::Box.extensions << TestFormattedWrapOverride
+      Prawn::Text::Box.extensions << formatted_wrap_override
       pdf.text_box('hello world', {})
-      Prawn::Text::Box.extensions.delete(TestFormattedWrapOverride)
+      Prawn::Text::Box.extensions.delete(formatted_wrap_override)
       text = PDF::Inspector::Text.analyze(pdf.render)
       expect(text.strings[0]).to eq('all your base are belong to us')
     end
   end
 
   describe 'Text::Formatted::Box#render' do
+    let(:fragment_callback_class) do
+      Class.new do
+        def initialize(_string, _number, _options); end
+
+        def render_behind(fragment); end
+
+        def render_in_front(fragment); end
+      end
+    end
+
     it 'handles newlines' do
       array = [{ text: "hello\nworld" }]
       options = { document: pdf }
@@ -377,11 +409,10 @@ describe Prawn::Text::Formatted::Box do
       expect(text.strings[2]).to eq(' olleh' * number_of_hellos)
       expect(text.strings[3]).to eq('?uoy')
     end
-  end
 
-  describe 'Text::Formatted::Box#render' do
     it 'is able to perform fragment callbacks' do
-      callback_object = TestFragmentCallback.new('something', 7, document: pdf)
+      callback_object =
+        fragment_callback_class.new('something', 7, document: pdf)
       allow(callback_object).to receive(:render_behind)
       allow(callback_object).to receive(:render_in_front)
       array = [
@@ -400,11 +431,12 @@ describe Prawn::Text::Formatted::Box do
     end
 
     it 'is able to perform fragment callbacks on multiple objects' do
-      callback_object = TestFragmentCallback.new('something', 7, document: pdf)
+      callback_object =
+        fragment_callback_class.new('something', 7, document: pdf)
       allow(callback_object).to receive(:render_behind)
       allow(callback_object).to receive(:render_in_front)
 
-      callback_object2 = TestFragmentCallback.new(
+      callback_object2 = fragment_callback_class.new(
         'something else', 14, document: pdf
       )
       allow(callback_object2).to receive(:render_behind)
@@ -432,11 +464,23 @@ describe Prawn::Text::Formatted::Box do
     end
 
     it 'fragment callbacks is able to define only the callback they need' do
-      behind = TestFragmentCallbackBehind.new(
+      behind = (
+        Class.new do
+          def initialize(_string, _number, _options); end
+
+          def render_behind(fragment); end
+        end
+      ).new(
         'something', 7,
         document: pdf
       )
-      in_front = TestFragmentCallbackInFront.new(
+      in_front = (
+        Class.new do
+          def initialize(_string, _number, _options); end
+
+          def render_in_front(fragment); end
+        end
+      ).new(
         'something', 7,
         document: pdf
       )
@@ -463,7 +507,7 @@ describe Prawn::Text::Formatted::Box do
       text_box.render
       contents = PDF::Inspector::Text.analyze(pdf.render)
       fonts = contents.font_settings.map { |e| e[:name] }
-      expect(fonts).to eq([:Helvetica, :"Times-Bold", :Helvetica])
+      expect(fonts).to eq(%i[Helvetica Times-Bold Helvetica])
       expect(contents.strings[0]).to eq('this contains ')
       expect(contents.strings[1]).to eq('Times-Bold')
       expect(contents.strings[2]).to eq(' text')
@@ -479,7 +523,7 @@ describe Prawn::Text::Formatted::Box do
       text_box.render
       contents = PDF::Inspector::Text.analyze(pdf.render)
       fonts = contents.font_settings.map { |e| e[:name] }
-      expect(fonts).to eq([:Helvetica, :"Helvetica-Bold", :Helvetica])
+      expect(fonts).to eq(%i[Helvetica Helvetica-Bold Helvetica])
       expect(contents.strings[0]).to eq('this contains ')
       expect(contents.strings[1]).to eq('bold')
       expect(contents.strings[2]).to eq(' text')
@@ -495,7 +539,7 @@ describe Prawn::Text::Formatted::Box do
       text_box.render
       contents = PDF::Inspector::Text.analyze(pdf.render)
       fonts = contents.font_settings.map { |e| e[:name] }
-      expect(fonts).to eq([:Helvetica, :"Helvetica-Oblique", :Helvetica])
+      expect(fonts).to eq(%i[Helvetica Helvetica-Oblique Helvetica])
     end
 
     it 'is able to set subscript' do
@@ -529,15 +573,16 @@ describe Prawn::Text::Formatted::Box do
     it 'is able to set compound bold and italic text' do
       array = [
         { text: 'this contains ' },
-        { text: 'bold italic', styles: [:bold, :italic] },
+        { text: 'bold italic', styles: %i[bold italic] },
         { text: ' text' }
       ]
       text_box = described_class.new(array, document: pdf)
       text_box.render
       contents = PDF::Inspector::Text.analyze(pdf.render)
       fonts = contents.font_settings.map { |e| e[:name] }
-      expect(fonts).to eq([:Helvetica, :"Helvetica-BoldOblique", :Helvetica])
+      expect(fonts).to eq(%i[Helvetica Helvetica-BoldOblique Helvetica])
     end
+
     it 'is able to underline' do
       array = [
         { text: 'this contains ' },
@@ -740,6 +785,20 @@ describe Prawn::Text::Formatted::Box do
       contents = PDF::Inspector::Text.analyze(pdf.render)
       expect(contents.word_spacing).to be_empty
     end
+
+    it 'raise an exception when align value is not a symbol' do
+      array = [
+        { text: 'hello world ' },
+        { text: "\n" },
+        { text: 'goodbye' }
+      ]
+      options = { document: pdf, align: 'justify' }
+      text_box = described_class.new(array, options)
+      expect { text_box.render }.to raise_error(
+        ArgumentError,
+        'align must be one of :left, :right, :center or :justify symbols'
+      )
+    end
   end
 
   describe 'Text::Formatted::Box#render with :valign => :center' do
@@ -784,42 +843,4 @@ describe Prawn::Text::Formatted::Box do
       expect(text_box.at[1]).to be_within(0.01).of(top_padding)
     end
   end
-
-  class TestFragmentCallback
-    def initialize(_string, _number, _options); end
-
-    def render_behind(fragment); end
-
-    def render_in_front(fragment); end
-  end
-
-  class TestFragmentCallbackBehind
-    def initialize(_string, _number, _options); end
-
-    def render_behind(fragment); end
-  end
-
-  class TestFragmentCallbackInFront
-    def initialize(_string, _number, _options); end
-
-    def render_in_front(fragment); end
-  end
-
-  # rubocop: disable RSpec/InstanceVariable
-  module TestFormattedWrapOverride
-    def wrap(_array)
-      initialize_wrap([{ text: 'all your base are belong to us' }])
-      @line_wrap.wrap_line(
-        document: @document,
-        kerning: @kerning,
-        width: 10_000,
-        arranger: @arranger
-      )
-      fragment = @arranger.retrieve_fragment
-      format_and_draw_fragment(fragment, 0, @line_wrap.width, 0)
-
-      []
-    end
-  end
-  # rubocop: enable RSpec/InstanceVariable
 end
