@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'spec_helper'
 
 describe Prawn::Text do
@@ -15,7 +17,7 @@ describe Prawn::Text do
   end
 
   describe '#text with inline styling' do
-    it 'should automatically move to a new page if the tallest fragment' \
+    it 'automatically moves to a new page if the tallest fragment' \
       " on the next line won't fit in the available space" do
       pdf.move_cursor_to(pdf.font.height)
       formatted = "this contains <font size='24'>sized</font> text"
